# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType


class Challenge(AWSObject):
    """
    `Challenge <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pcaconnectorscep-challenge.html>`__
    """

    resource_type = "AWS::PCAConnectorSCEP::Challenge"

    props: PropsDictType = {
        "ConnectorArn": (str, True),
        "Tags": (dict, False),
    }


class IntuneConfiguration(AWSProperty):
    """
    `IntuneConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-pcaconnectorscep-connector-intuneconfiguration.html>`__
    """

    props: PropsDictType = {
        "AzureApplicationId": (str, True),
        "Domain": (str, True),
    }


class MobileDeviceManagement(AWSProperty):
    """
    `MobileDeviceManagement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-pcaconnectorscep-connector-mobiledevicemanagement.html>`__
    """

    props: PropsDictType = {
        "Intune": (IntuneConfiguration, True),
    }


class Connector(AWSObject):
    """
    `Connector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pcaconnectorscep-connector.html>`__
    """

    resource_type = "AWS::PCAConnectorSCEP::Connector"

    props: PropsDictType = {
        "CertificateAuthorityArn": (str, True),
        "MobileDeviceManagement": (MobileDeviceManagement, False),
        "Tags": (dict, False),
    }


class OpenIdConfiguration(AWSProperty):
    """
    `OpenIdConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-pcaconnectorscep-connector-openidconfiguration.html>`__
    """

    props: PropsDictType = {
        "Audience": (str, False),
        "Issuer": (str, False),
        "Subject": (str, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags


class Profile(AWSObject):
    """
    `Profile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53profiles-profile.html>`__
    """

    resource_type = "AWS::Route53Profiles::Profile"

    props: PropsDictType = {
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class ProfileAssociation(AWSObject):
    """
    `ProfileAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53profiles-profileassociation.html>`__
    """

    resource_type = "AWS::Route53Profiles::ProfileAssociation"

    props: PropsDictType = {
        "Arn": (str, False),
        "Name": (str, True),
        "ProfileId": (str, True),
        "ResourceId": (str, True),
        "Tags": (Tags, False),
    }


class ProfileResourceAssociation(AWSObject):
    """
    `ProfileResourceAssociation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53profiles-profileresourceassociation.html>`__
    """

    resource_type = "AWS::Route53Profiles::ProfileResourceAssociation"

    props: PropsDictType = {
        "Name": (str, True),
        "ProfileId": (str, True),
        "ResourceArn": (str, True),
        "ResourceProperties": (str, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class RuleGroupsNamespace(AWSObject):
    """
    `RuleGroupsNamespace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html>`__
    """

    resource_type = "AWS::APS::RuleGroupsNamespace"

    props: PropsDictType = {
        "Data": (str, True),
        "Name": (str, True),
        "Tags": (Tags, False),
        "Workspace": (str, True),
    }


class AmpConfiguration(AWSProperty):
    """
    `AmpConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-scraper-ampconfiguration.html>`__
    """

    props: PropsDictType = {
        "WorkspaceArn": (str, True),
    }


class Destination(AWSProperty):
    """
    `Destination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-scraper-destination.html>`__
    """

    props: PropsDictType = {
        "AmpConfiguration": (AmpConfiguration, True),
    }


class ScrapeConfiguration(AWSProperty):
    """
    `ScrapeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-scraper-scrapeconfiguration.html>`__
    """

    props: PropsDictType = {
        "ConfigurationBlob": (str, True),
    }


class EksConfiguration(AWSProperty):
    """
    `EksConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-scraper-eksconfiguration.html>`__
    """

    props: PropsDictType = {
        "ClusterArn": (str, True),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], True),
    }


class Source(AWSProperty):
    """
    `Source <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-scraper-source.html>`__
    """

    props: PropsDictType = {
        "EksConfiguration": (EksConfiguration, True),
    }


class Scraper(AWSObject):
    """
    `Scraper <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-scraper.html>`__
    """

    resource_type = "AWS::APS::Scraper"

    props: PropsDictType = {
        "Alias": (str, False),
        "Destination": (Destination, True),
        "ScrapeConfiguration": (ScrapeConfiguration, True),
        "Source": (Source, True),
        "Tags": (Tags, False),
    }


class LoggingConfiguration(AWSProperty):
    """
    `LoggingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aps-workspace-loggingconfiguration.html>`__
    """

    props: PropsDictType = {
        "LogGroupArn": (str, False),
    }


class Workspace(AWSObject):
    """
    `Workspace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-workspace.html>`__
    """

    resource_type = "AWS::APS::Workspace"

    props: PropsDictType = {
        "AlertManagerDefinition": (str, False),
        "Alias": (str, False),
        "KmsKeyArn": (str, False),
        "LoggingConfiguration": (LoggingConfiguration, False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class VectorSearchConfiguration(AWSProperty):
    """
    `VectorSearchConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-neptunegraph-graph-vectorsearchconfiguration.html>`__
    """

    props: PropsDictType = {
        "VectorSearchDimension": (integer, True),
    }


class Graph(AWSObject):
    """
    `Graph <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-neptunegraph-graph.html>`__
    """

    resource_type = "AWS::NeptuneGraph::Graph"

    props: PropsDictType = {
        "DeletionProtection": (boolean, False),
        "GraphName": (str, False),
        "ProvisionedMemory": (integer, True),
        "PublicConnectivity": (boolean, False),
        "ReplicaCount": (integer, False),
        "Tags": (Tags, False),
        "VectorSearchConfiguration": (VectorSearchConfiguration, False),
    }


class PrivateGraphEndpoint(AWSObject):
    """
    `PrivateGraphEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-neptunegraph-privategraphendpoint.html>`__
    """

    resource_type = "AWS::NeptuneGraph::PrivateGraphEndpoint"

    props: PropsDictType = {
        "GraphIdentifier": (str, True),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
        "VpcId": (str, True),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType


class DataQuery(AWSProperty):
    """
    `DataQuery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-dataquery.html>`__
    """

    props: PropsDictType = {
        "QueryStatement": (str, True),
        "TableConfigurations": (dict, False),
    }


class S3OutputConfigurations(AWSProperty):
    """
    `S3OutputConfigurations <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-s3outputconfigurations.html>`__
    """

    props: PropsDictType = {
        "Compression": (str, True),
        "Format": (str, True),
        "OutputType": (str, True),
        "Overwrite": (str, True),
    }


class S3Destination(AWSProperty):
    """
    `S3Destination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-s3destination.html>`__
    """

    props: PropsDictType = {
        "S3Bucket": (str, True),
        "S3OutputConfigurations": (S3OutputConfigurations, True),
        "S3Prefix": (str, True),
        "S3Region": (str, True),
    }


class DestinationConfigurations(AWSProperty):
    """
    `DestinationConfigurations <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-destinationconfigurations.html>`__
    """

    props: PropsDictType = {
        "S3Destination": (S3Destination, True),
    }


class RefreshCadence(AWSProperty):
    """
    `RefreshCadence <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-refreshcadence.html>`__
    """

    props: PropsDictType = {
        "Frequency": (str, True),
    }


class ExportProperty(AWSProperty):
    """
    `ExportProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-export.html>`__
    """

    props: PropsDictType = {
        "DataQuery": (DataQuery, True),
        "Description": (str, False),
        "DestinationConfigurations": (DestinationConfigurations, True),
        "ExportArn": (str, False),
        "Name": (str, True),
        "RefreshCadence": (RefreshCadence, True),
    }


class ResourceTag(AWSProperty):
    """
    `ResourceTag <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bcmdataexports-export-resourcetag.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Value": (str, True),
    }


class Export(AWSObject):
    """
    `Export <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bcmdataexports-export.html>`__
    """

    resource_type = "AWS::BCMDataExports::Export"

    props: PropsDictType = {
        "Export": (ExportProperty, True),
        "Tags": ([ResourceTag], False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double


class DeliveryOptions(AWSProperty):
    """
    `DeliveryOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-deliveryoptions.html>`__
    """

    props: PropsDictType = {
        "SendingPoolName": (str, False),
        "TlsPolicy": (str, False),
    }


class ReputationOptions(AWSProperty):
    """
    `ReputationOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-reputationoptions.html>`__
    """

    props: PropsDictType = {
        "ReputationMetricsEnabled": (boolean, False),
    }


class SendingOptions(AWSProperty):
    """
    `SendingOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-sendingoptions.html>`__
    """

    props: PropsDictType = {
        "SendingEnabled": (boolean, False),
    }


class SuppressionOptions(AWSProperty):
    """
    `SuppressionOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-suppressionoptions.html>`__
    """

    props: PropsDictType = {
        "SuppressedReasons": ([str], False),
    }


class TrackingOptions(AWSProperty):
    """
    `TrackingOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-trackingoptions.html>`__
    """

    props: PropsDictType = {
        "CustomRedirectDomain": (str, False),
    }


class DashboardOptions(AWSProperty):
    """
    `DashboardOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-dashboardoptions.html>`__
    """

    props: PropsDictType = {
        "EngagementMetrics": (str, True),
    }


class GuardianOptions(AWSProperty):
    """
    `GuardianOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-guardianoptions.html>`__
    """

    props: PropsDictType = {
        "OptimizedSharedDelivery": (str, True),
    }


class VdmOptions(AWSProperty):
    """
    `VdmOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationset-vdmoptions.html>`__
    """

    props: PropsDictType = {
        "DashboardOptions": (DashboardOptions, False),
        "GuardianOptions": (GuardianOptions, False),
    }


class ConfigurationSet(AWSObject):
    """
    `ConfigurationSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationset.html>`__
    """

    resource_type = "AWS::SES::ConfigurationSet"

    props: PropsDictType = {
        "DeliveryOptions": (DeliveryOptions, False),
        "Name": (str, False),
        "ReputationOptions": (ReputationOptions, False),
        "SendingOptions": (SendingOptions, False),
        "SuppressionOptions": (SuppressionOptions, False),
        "TrackingOptions": (TrackingOptions, False),
        "VdmOptions": (VdmOptions, False),
    }


class DimensionConfiguration(AWSProperty):
    """
    `DimensionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-dimensionconfiguration.html>`__
    """

    props: PropsDictType = {
        "DefaultDimensionValue": (str, True),
        "DimensionName": (str, True),
        "DimensionValueSource": (str, True),
    }


class CloudWatchDestination(AWSProperty):
    """
    `CloudWatchDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-cloudwatchdestination.html>`__
    """

    props: PropsDictType = {
        "DimensionConfigurations": ([DimensionConfiguration], False),
    }


class EventBridgeDestination(AWSProperty):
    """
    `EventBridgeDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-eventbridgedestination.html>`__
    """

    props: PropsDictType = {
        "EventBusArn": (str, True),
    }


class KinesisFirehoseDestination(AWSProperty):
    """
    `KinesisFirehoseDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-kinesisfirehosedestination.html>`__
    """

    props: PropsDictType = {
        "DeliveryStreamARN": (str, True),
        "IAMRoleARN": (str, True),
    }


class SnsDestination(AWSProperty):
    """
    `SnsDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-snsdestination.html>`__
    """

    props: PropsDictType = {
        "TopicARN": (str, True),
    }


class EventDestination(AWSProperty):
    """
    `EventDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-configurationseteventdestination-eventdestination.html>`__
    """

    props: PropsDictType = {
        "CloudWatchDestination": (CloudWatchDestination, False),
        "Enabled": (boolean, False),
        "EventBridgeDestination": (EventBridgeDestination, False),
        "KinesisFirehoseDestination": (KinesisFirehoseDestination, False),
        "MatchingEventTypes": ([str], True),
        "Name": (str, False),
        "SnsDestination": (SnsDestination, False),
    }


class ConfigurationSetEventDestination(AWSObject):
    """
    `ConfigurationSetEventDestination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-configurationseteventdestination.html>`__
    """

    resource_type = "AWS::SES::ConfigurationSetEventDestination"

    props: PropsDictType = {
        "ConfigurationSetName": (str, True),
        "EventDestination": (EventDestination, True),
    }


class Topic(AWSProperty):
    """
    `Topic <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-contactlist-topic.html>`__
    """

    props: PropsDictType = {
        "DefaultSubscriptionStatus": (str, True),
        "Description": (str, False),
        "DisplayName": (str, True),
        "TopicName": (str, True),
    }


class ContactList(AWSObject):
    """
    `ContactList <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-contactlist.html>`__
    """

    resource_type = "AWS::SES::ContactList"

    props: PropsDictType = {
        "ContactListName": (str, False),
        "Description": (str, False),
        "Tags": (Tags, False),
        "Topics": ([Topic], False),
    }


class DedicatedIpPool(AWSObject):
    """
    `DedicatedIpPool <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-dedicatedippool.html>`__
    """

    resource_type = "AWS::SES::DedicatedIpPool"

    props: PropsDictType = {
        "PoolName": (str, False),
        "ScalingMode": (str, False),
    }


class ConfigurationSetAttributes(AWSProperty):
    """
    `ConfigurationSetAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-configurationsetattributes.html>`__
    """

    props: PropsDictType = {
        "ConfigurationSetName": (str, False),
    }


class DkimAttributes(AWSProperty):
    """
    `DkimAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-dkimattributes.html>`__
    """

    props: PropsDictType = {
        "SigningEnabled": (boolean, False),
    }


class DkimSigningAttributes(AWSProperty):
    """
    `DkimSigningAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-dkimsigningattributes.html>`__
    """

    props: PropsDictType = {
        "DomainSigningPrivateKey": (str, False),
        "DomainSigningSelector": (str, False),
        "NextSigningKeyLength": (str, False),
    }


class FeedbackAttributes(AWSProperty):
    """
    `FeedbackAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-feedbackattributes.html>`__
    """

    props: PropsDictType = {
        "EmailForwardingEnabled": (boolean, False),
    }


class MailFromAttributes(AWSProperty):
    """
    `MailFromAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-emailidentity-mailfromattributes.html>`__
    """

    props: PropsDictType = {
        "BehaviorOnMxFailure": (str, False),
        "MailFromDomain": (str, False),
    }


class EmailIdentity(AWSObject):
    """
    `EmailIdentity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-emailidentity.html>`__
    """

    resource_type = "AWS::SES::EmailIdentity"

    props: PropsDictType = {
        "ConfigurationSetAttributes": (ConfigurationSetAttributes, False),
        "DkimAttributes": (DkimAttributes, False),
        "DkimSigningAttributes": (DkimSigningAttributes, False),
        "EmailIdentity": (str, True),
        "FeedbackAttributes": (FeedbackAttributes, False),
        "MailFromAttributes": (MailFromAttributes, False),
    }


class MailManagerAddonInstance(AWSObject):
    """
    `MailManagerAddonInstance <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanageraddoninstance.html>`__
    """

    resource_type = "AWS::SES::MailManagerAddonInstance"

    props: PropsDictType = {
        "AddonSubscriptionId": (str, True),
        "Tags": (Tags, False),
    }


class MailManagerAddonSubscription(AWSObject):
    """
    `MailManagerAddonSubscription <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanageraddonsubscription.html>`__
    """

    resource_type = "AWS::SES::MailManagerAddonSubscription"

    props: PropsDictType = {
        "AddonName": (str, True),
        "Tags": (Tags, False),
    }


class ArchiveRetention(AWSProperty):
    """
    `ArchiveRetention <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerarchive-archiveretention.html>`__
    """

    props: PropsDictType = {
        "RetentionPeriod": (str, True),
    }


class MailManagerArchive(AWSObject):
    """
    `MailManagerArchive <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanagerarchive.html>`__
    """

    resource_type = "AWS::SES::MailManagerArchive"

    props: PropsDictType = {
        "ArchiveName": (str, False),
        "KmsKeyArn": (str, False),
        "Retention": (ArchiveRetention, False),
        "Tags": (Tags, False),
    }


class IngressPointConfiguration(AWSProperty):
    """
    `IngressPointConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanageringresspoint-ingresspointconfiguration.html>`__
    """

    props: PropsDictType = {
        "SecretArn": (str, False),
        "SmtpPassword": (str, False),
    }


class MailManagerIngressPoint(AWSObject):
    """
    `MailManagerIngressPoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanageringresspoint.html>`__
    """

    resource_type = "AWS::SES::MailManagerIngressPoint"

    props: PropsDictType = {
        "IngressPointConfiguration": (IngressPointConfiguration, False),
        "IngressPointName": (str, False),
        "RuleSetId": (str, True),
        "StatusToUpdate": (str, False),
        "Tags": (Tags, False),
        "TrafficPolicyId": (str, True),
        "Type": (str, True),
    }


class RelayAuthentication(AWSProperty):
    """
    `RelayAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerrelay-relayauthentication.html>`__
    """

    props: PropsDictType = {
        "NoAuthentication": (dict, False),
        "SecretArn": (str, False),
    }


class MailManagerRelay(AWSObject):
    """
    `MailManagerRelay <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanagerrelay.html>`__
    """

    resource_type = "AWS::SES::MailManagerRelay"

    props: PropsDictType = {
        "Authentication": (RelayAuthentication, True),
        "RelayName": (str, False),
        "ServerName": (str, True),
        "ServerPort": (double, True),
        "Tags": (Tags, False),
    }


class AddHeaderAction(AWSProperty):
    """
    `AddHeaderAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-addheaderaction.html>`__
    """

    props: PropsDictType = {
        "HeaderName": (str, True),
        "HeaderValue": (str, True),
    }


class ArchiveAction(AWSProperty):
    """
    `ArchiveAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-archiveaction.html>`__
    """

    props: PropsDictType = {
        "ActionFailurePolicy": (str, False),
        "TargetArchive": (str, True),
    }


class DeliverToMailboxAction(AWSProperty):
    """
    `DeliverToMailboxAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-delivertomailboxaction.html>`__
    """

    props: PropsDictType = {
        "ActionFailurePolicy": (str, False),
        "MailboxArn": (str, True),
        "RoleArn": (str, True),
    }


class MailManagerS3Action(AWSProperty):
    """
    `MailManagerS3Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-s3action.html>`__
    """

    props: PropsDictType = {
        "ActionFailurePolicy": (str, False),
        "RoleArn": (str, True),
        "S3Bucket": (str, True),
        "S3Prefix": (str, False),
        "S3SseKmsKeyId": (str, False),
    }


class RelayAction(AWSProperty):
    """
    `RelayAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-relayaction.html>`__
    """

    props: PropsDictType = {
        "ActionFailurePolicy": (str, False),
        "MailFrom": (str, False),
        "Relay": (str, True),
    }


class ReplaceRecipientAction(AWSProperty):
    """
    `ReplaceRecipientAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-replacerecipientaction.html>`__
    """

    props: PropsDictType = {
        "ReplaceWith": ([str], False),
    }


class SendAction(AWSProperty):
    """
    `SendAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-sendaction.html>`__
    """

    props: PropsDictType = {
        "ActionFailurePolicy": (str, False),
        "RoleArn": (str, True),
    }


class RuleAction(AWSProperty):
    """
    `RuleAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruleaction.html>`__
    """

    props: PropsDictType = {
        "AddHeader": (AddHeaderAction, False),
        "Archive": (ArchiveAction, False),
        "DeliverToMailbox": (DeliverToMailboxAction, False),
        "Drop": (dict, False),
        "Relay": (RelayAction, False),
        "ReplaceRecipient": (ReplaceRecipientAction, False),
        "Send": (SendAction, False),
        "WriteToS3": (MailManagerS3Action, False),
    }


class RuleBooleanToEvaluate(AWSProperty):
    """
    `RuleBooleanToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulebooleantoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class RuleBooleanExpression(AWSProperty):
    """
    `RuleBooleanExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulebooleanexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (RuleBooleanToEvaluate, True),
        "Operator": (str, True),
    }


class RuleDmarcExpression(AWSProperty):
    """
    `RuleDmarcExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruledmarcexpression.html>`__
    """

    props: PropsDictType = {
        "Operator": (str, True),
        "Values": ([str], True),
    }


class RuleIpToEvaluate(AWSProperty):
    """
    `RuleIpToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruleiptoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class RuleIpExpression(AWSProperty):
    """
    `RuleIpExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruleipexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (RuleIpToEvaluate, True),
        "Operator": (str, True),
        "Values": ([str], True),
    }


class RuleNumberToEvaluate(AWSProperty):
    """
    `RuleNumberToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulenumbertoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class RuleNumberExpression(AWSProperty):
    """
    `RuleNumberExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulenumberexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (RuleNumberToEvaluate, True),
        "Operator": (str, True),
        "Value": (double, True),
    }


class RuleStringToEvaluate(AWSProperty):
    """
    `RuleStringToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulestringtoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, False),
        "MimeHeaderAttribute": (str, False),
    }


class RuleStringExpression(AWSProperty):
    """
    `RuleStringExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulestringexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (RuleStringToEvaluate, True),
        "Operator": (str, True),
        "Values": ([str], True),
    }


class Analysis(AWSProperty):
    """
    `Analysis <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-analysis.html>`__
    """

    props: PropsDictType = {
        "Analyzer": (str, True),
        "ResultField": (str, True),
    }


class RuleVerdictToEvaluate(AWSProperty):
    """
    `RuleVerdictToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruleverdicttoevaluate.html>`__
    """

    props: PropsDictType = {
        "Analysis": (Analysis, False),
        "Attribute": (str, False),
    }


class RuleVerdictExpression(AWSProperty):
    """
    `RuleVerdictExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-ruleverdictexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (RuleVerdictToEvaluate, True),
        "Operator": (str, True),
        "Values": ([str], True),
    }


class RuleCondition(AWSProperty):
    """
    `RuleCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rulecondition.html>`__
    """

    props: PropsDictType = {
        "BooleanExpression": (RuleBooleanExpression, False),
        "DmarcExpression": (RuleDmarcExpression, False),
        "IpExpression": (RuleIpExpression, False),
        "NumberExpression": (RuleNumberExpression, False),
        "StringExpression": (RuleStringExpression, False),
        "VerdictExpression": (RuleVerdictExpression, False),
    }


class MailManagerRule(AWSProperty):
    """
    `MailManagerRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagerruleset-rule.html>`__
    """

    props: PropsDictType = {
        "Actions": ([RuleAction], True),
        "Conditions": ([RuleCondition], False),
        "Name": (str, False),
        "Unless": ([RuleCondition], False),
    }


class MailManagerRuleSet(AWSObject):
    """
    `MailManagerRuleSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanagerruleset.html>`__
    """

    resource_type = "AWS::SES::MailManagerRuleSet"

    props: PropsDictType = {
        "RuleSetName": (str, False),
        "Rules": ([MailManagerRule], True),
        "Tags": (Tags, False),
    }


class IngressAnalysis(AWSProperty):
    """
    `IngressAnalysis <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressanalysis.html>`__
    """

    props: PropsDictType = {
        "Analyzer": (str, True),
        "ResultField": (str, True),
    }


class IngressBooleanToEvaluate(AWSProperty):
    """
    `IngressBooleanToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressbooleantoevaluate.html>`__
    """

    props: PropsDictType = {
        "Analysis": (IngressAnalysis, True),
    }


class IngressBooleanExpression(AWSProperty):
    """
    `IngressBooleanExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressbooleanexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (IngressBooleanToEvaluate, True),
        "Operator": (str, True),
    }


class IngressIpToEvaluate(AWSProperty):
    """
    `IngressIpToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressiptoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class IngressIpv4Expression(AWSProperty):
    """
    `IngressIpv4Expression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressipv4expression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (IngressIpToEvaluate, True),
        "Operator": (str, True),
        "Values": ([str], True),
    }


class IngressStringToEvaluate(AWSProperty):
    """
    `IngressStringToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressstringtoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class IngressStringExpression(AWSProperty):
    """
    `IngressStringExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingressstringexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (IngressStringToEvaluate, True),
        "Operator": (str, True),
        "Values": ([str], True),
    }


class IngressTlsProtocolToEvaluate(AWSProperty):
    """
    `IngressTlsProtocolToEvaluate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingresstlsprotocoltoevaluate.html>`__
    """

    props: PropsDictType = {
        "Attribute": (str, True),
    }


class IngressTlsProtocolExpression(AWSProperty):
    """
    `IngressTlsProtocolExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-ingresstlsprotocolexpression.html>`__
    """

    props: PropsDictType = {
        "Evaluate": (IngressTlsProtocolToEvaluate, True),
        "Operator": (str, True),
        "Value": (str, True),
    }


class PolicyCondition(AWSProperty):
    """
    `PolicyCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-policycondition.html>`__
    """

    props: PropsDictType = {
        "BooleanExpression": (IngressBooleanExpression, False),
        "IpExpression": (IngressIpv4Expression, False),
        "StringExpression": (IngressStringExpression, False),
        "TlsExpression": (IngressTlsProtocolExpression, False),
    }


class PolicyStatement(AWSProperty):
    """
    `PolicyStatement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-mailmanagertrafficpolicy-policystatement.html>`__
    """

    props: PropsDictType = {
        "Action": (str, True),
        "Conditions": ([PolicyCondition], True),
    }


class MailManagerTrafficPolicy(AWSObject):
    """
    `MailManagerTrafficPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-mailmanagertrafficpolicy.html>`__
    """

    resource_type = "AWS::SES::MailManagerTrafficPolicy"

    props: PropsDictType = {
        "DefaultAction": (str, True),
        "MaxMessageSizeBytes": (double, False),
        "PolicyStatements": ([PolicyStatement], True),
        "Tags": (Tags, False),
        "TrafficPolicyName": (str, False),
    }


class IpFilter(AWSProperty):
    """
    `IpFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptfilter-ipfilter.html>`__
    """

    props: PropsDictType = {
        "Cidr": (str, True),
        "Policy": (str, True),
    }


class Filter(AWSProperty):
    """
    `Filter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptfilter-filter.html>`__
    """

    props: PropsDictType = {
        "IpFilter": (IpFilter, True),
        "Name": (str, False),
    }


class ReceiptFilter(AWSObject):
    """
    `ReceiptFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptfilter.html>`__
    """

    resource_type = "AWS::SES::ReceiptFilter"

    props: PropsDictType = {
        "Filter": (Filter, True),
    }


class BounceAction(AWSProperty):
    """
    `BounceAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-bounceaction.html>`__
    """

    props: PropsDictType = {
        "Message": (str, True),
        "Sender": (str, True),
        "SmtpReplyCode": (str, True),
        "StatusCode": (str, False),
        "TopicArn": (str, False),
    }


class LambdaAction(AWSProperty):
    """
    `LambdaAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-lambdaaction.html>`__
    """

    props: PropsDictType = {
        "FunctionArn": (str, True),
        "InvocationType": (str, False),
        "TopicArn": (str, False),
    }


class S3Action(AWSProperty):
    """
    `S3Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-s3action.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
        "IamRoleArn": (str, False),
        "KmsKeyArn": (str, False),
        "ObjectKeyPrefix": (str, False),
        "TopicArn": (str, False),
    }


class SNSAction(AWSProperty):
    """
    `SNSAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-snsaction.html>`__
    """

    props: PropsDictType = {
        "Encoding": (str, False),
        "TopicArn": (str, False),
    }


class StopAction(AWSProperty):
    """
    `StopAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-stopaction.html>`__
    """

    props: PropsDictType = {
        "Scope": (str, True),
        "TopicArn": (str, False),
    }


class WorkmailAction(AWSProperty):
    """
    `WorkmailAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-workmailaction.html>`__
    """

    props: PropsDictType = {
        "OrganizationArn": (str, True),
        "TopicArn": (str, False),
    }


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-action.html>`__
    """

    props: PropsDictType = {
        "AddHeaderAction": (AddHeaderAction, False),
        "BounceAction": (BounceAction, False),
        "LambdaAction": (LambdaAction, False),
        "S3Action": (S3Action, False),
        "SNSAction": (SNSAction, False),
        "StopAction": (StopAction, False),
        "WorkmailAction": (WorkmailAction, False),
    }


class Rule(AWSProperty):
    """
    `Rule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-receiptrule-rule.html>`__
    """

    props: PropsDictType = {
        "Actions": ([Action], False),
        "Enabled": (boolean, False),
        "Name": (str, False),
        "Recipients": ([str], False),
        "ScanEnabled": (boolean, False),
        "TlsPolicy": (str, False),
    }


class ReceiptRule(AWSObject):
    """
    `ReceiptRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptrule.html>`__
    """

    resource_type = "AWS::SES::ReceiptRule"

    props: PropsDictType = {
        "After": (str, False),
        "Rule": (Rule, True),
        "RuleSetName": (str, True),
    }


class ReceiptRuleSet(AWSObject):
    """
    `ReceiptRuleSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptruleset.html>`__
    """

    resource_type = "AWS::SES::ReceiptRuleSet"

    props: PropsDictType = {
        "RuleSetName": (str, False),
    }


class EmailTemplate(AWSProperty):
    """
    `EmailTemplate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-template-template.html>`__
    """

    props: PropsDictType = {
        "HtmlPart": (str, False),
        "SubjectPart": (str, True),
        "TemplateName": (str, False),
        "TextPart": (str, False),
    }


class Template(AWSObject):
    """
    `Template <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-template.html>`__
    """

    resource_type = "AWS::SES::Template"

    props: PropsDictType = {
        "Template": (EmailTemplate, False),
    }


class DashboardAttributes(AWSProperty):
    """
    `DashboardAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-vdmattributes-dashboardattributes.html>`__
    """

    props: PropsDictType = {
        "EngagementMetrics": (str, False),
    }


class GuardianAttributes(AWSProperty):
    """
    `GuardianAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ses-vdmattributes-guardianattributes.html>`__
    """

    props: PropsDictType = {
        "OptimizedSharedDelivery": (str, False),
    }


class VdmAttributes(AWSObject):
    """
    `VdmAttributes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-vdmattributes.html>`__
    """

    resource_type = "AWS::SES::VdmAttributes"

    props: PropsDictType = {
        "DashboardAttributes": (DashboardAttributes, False),
        "GuardianAttributes": (GuardianAttributes, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType


class ConfigurationDefinition(AWSProperty):
    """
    `ConfigurationDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmquicksetup-configurationmanager-configurationdefinition.html>`__
    """

    props: PropsDictType = {
        "LocalDeploymentAdministrationRoleArn": (str, False),
        "LocalDeploymentExecutionRoleName": (str, False),
        "Parameters": (dict, True),
        "Type": (str, True),
        "TypeVersion": (str, False),
        "id": (str, False),
    }


class ConfigurationManager(AWSObject):
    """
    `ConfigurationManager <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ssmquicksetup-configurationmanager.html>`__
    """

    resource_type = "AWS::SSMQuickSetup::ConfigurationManager"

    props: PropsDictType = {
        "ConfigurationDefinitions": ([ConfigurationDefinition], True),
        "Description": (str, False),
        "Name": (str, False),
        "Tags": (dict, False),
    }


class StatusSummary(AWSProperty):
    """
    `StatusSummary <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssmquicksetup-configurationmanager-statussummary.html>`__
    """

    props: PropsDictType = {
        "LastUpdatedAt": (str, True),
        "Status": (str, False),
        "StatusDetails": (dict, False),
        "StatusMessage": (str, False),
        "StatusType": (str, True),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import double


class AttachmentsConfiguration(AWSProperty):
    """
    `AttachmentsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-application-attachmentsconfiguration.html>`__
    """

    props: PropsDictType = {
        "AttachmentsControlMode": (str, True),
    }


class AutoSubscriptionConfiguration(AWSProperty):
    """
    `AutoSubscriptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-application-autosubscriptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "AutoSubscribe": (str, True),
        "DefaultSubscriptionType": (str, False),
    }


class EncryptionConfiguration(AWSProperty):
    """
    `EncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-application-encryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
    }


class PersonalizationConfiguration(AWSProperty):
    """
    `PersonalizationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-application-personalizationconfiguration.html>`__
    """

    props: PropsDictType = {
        "PersonalizationControlMode": (str, True),
    }


class QAppsConfiguration(AWSProperty):
    """
    `QAppsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-application-qappsconfiguration.html>`__
    """

    props: PropsDictType = {
        "QAppsControlMode": (str, True),
    }


class Application(AWSObject):
    """
    `Application <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-application.html>`__
    """

    resource_type = "AWS::QBusiness::Application"

    props: PropsDictType = {
        "AttachmentsConfiguration": (AttachmentsConfiguration, False),
        "AutoSubscriptionConfiguration": (AutoSubscriptionConfiguration, False),
        "ClientIdsForOIDC": ([str], False),
        "Description": (str, False),
        "DisplayName": (str, True),
        "EncryptionConfiguration": (EncryptionConfiguration, False),
        "IamIdentityProviderArn": (str, False),
        "IdentityCenterInstanceArn": (str, False),
        "IdentityType": (str, False),
        "PersonalizationConfiguration": (PersonalizationConfiguration, False),
        "QAppsConfiguration": (QAppsConfiguration, False),
        "RoleArn": (str, False),
        "Tags": (Tags, False),
    }


class DataSourceVpcConfiguration(AWSProperty):
    """
    `DataSourceVpcConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-datasourcevpcconfiguration.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
    }


class DocumentAttributeValue(AWSProperty):
    """
    `DocumentAttributeValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-documentattributevalue.html>`__
    """

    props: PropsDictType = {
        "DateValue": (str, False),
        "LongValue": (double, False),
        "StringListValue": ([str], False),
        "StringValue": (str, False),
    }


class DocumentAttributeCondition(AWSProperty):
    """
    `DocumentAttributeCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-documentattributecondition.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Operator": (str, True),
        "Value": (DocumentAttributeValue, False),
    }


class HookConfiguration(AWSProperty):
    """
    `HookConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-hookconfiguration.html>`__
    """

    props: PropsDictType = {
        "InvocationCondition": (DocumentAttributeCondition, False),
        "LambdaArn": (str, False),
        "RoleArn": (str, False),
        "S3BucketName": (str, False),
    }


class DocumentAttributeTarget(AWSProperty):
    """
    `DocumentAttributeTarget <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-documentattributetarget.html>`__
    """

    props: PropsDictType = {
        "AttributeValueOperator": (str, False),
        "Key": (str, True),
        "Value": (DocumentAttributeValue, False),
    }


class InlineDocumentEnrichmentConfiguration(AWSProperty):
    """
    `InlineDocumentEnrichmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-inlinedocumentenrichmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "Condition": (DocumentAttributeCondition, False),
        "DocumentContentOperator": (str, False),
        "Target": (DocumentAttributeTarget, False),
    }


class DocumentEnrichmentConfiguration(AWSProperty):
    """
    `DocumentEnrichmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-datasource-documentenrichmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "InlineConfigurations": ([InlineDocumentEnrichmentConfiguration], False),
        "PostExtractionHookConfiguration": (HookConfiguration, False),
        "PreExtractionHookConfiguration": (HookConfiguration, False),
    }


class DataSource(AWSObject):
    """
    `DataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-datasource.html>`__
    """

    resource_type = "AWS::QBusiness::DataSource"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "Configuration": (dict, True),
        "Description": (str, False),
        "DisplayName": (str, True),
        "DocumentEnrichmentConfiguration": (DocumentEnrichmentConfiguration, False),
        "IndexId": (str, True),
        "RoleArn": (str, False),
        "SyncSchedule": (str, False),
        "Tags": (Tags, False),
        "VpcConfiguration": (DataSourceVpcConfiguration, False),
    }


class DocumentAttributeConfiguration(AWSProperty):
    """
    `DocumentAttributeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-index-documentattributeconfiguration.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "Search": (str, False),
        "Type": (str, False),
    }


class IndexCapacityConfiguration(AWSProperty):
    """
    `IndexCapacityConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-index-indexcapacityconfiguration.html>`__
    """

    props: PropsDictType = {
        "Units": (double, False),
    }


class Index(AWSObject):
    """
    `Index <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-index.html>`__
    """

    resource_type = "AWS::QBusiness::Index"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "CapacityConfiguration": (IndexCapacityConfiguration, False),
        "Description": (str, False),
        "DisplayName": (str, True),
        "DocumentAttributeConfigurations": ([DocumentAttributeConfiguration], False),
        "Tags": (Tags, False),
        "Type": (str, False),
    }


class S3(AWSProperty):
    """
    `S3 <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-s3.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, True),
        "Key": (str, True),
    }


class APISchema(AWSProperty):
    """
    `APISchema <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-apischema.html>`__
    """

    props: PropsDictType = {
        "Payload": (str, False),
        "S3": (S3, False),
    }


class CustomPluginConfiguration(AWSProperty):
    """
    `CustomPluginConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-custompluginconfiguration.html>`__
    """

    props: PropsDictType = {
        "ApiSchema": (APISchema, True),
        "ApiSchemaType": (str, True),
        "Description": (str, True),
    }


class BasicAuthConfiguration(AWSProperty):
    """
    `BasicAuthConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-basicauthconfiguration.html>`__
    """

    props: PropsDictType = {
        "RoleArn": (str, True),
        "SecretArn": (str, True),
    }


class OAuth2ClientCredentialConfiguration(AWSProperty):
    """
    `OAuth2ClientCredentialConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-oauth2clientcredentialconfiguration.html>`__
    """

    props: PropsDictType = {
        "RoleArn": (str, True),
        "SecretArn": (str, True),
    }


class PluginAuthConfiguration(AWSProperty):
    """
    `PluginAuthConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-plugin-pluginauthconfiguration.html>`__
    """

    props: PropsDictType = {
        "BasicAuthConfiguration": (BasicAuthConfiguration, False),
        "NoAuthConfiguration": (dict, False),
        "OAuth2ClientCredentialConfiguration": (
            OAuth2ClientCredentialConfiguration,
            False,
        ),
    }


class Plugin(AWSObject):
    """
    `Plugin <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-plugin.html>`__
    """

    resource_type = "AWS::QBusiness::Plugin"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "AuthConfiguration": (PluginAuthConfiguration, True),
        "CustomPluginConfiguration": (CustomPluginConfiguration, False),
        "DisplayName": (str, True),
        "ServerUrl": (str, False),
        "State": (str, False),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class KendraIndexConfiguration(AWSProperty):
    """
    `KendraIndexConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-retriever-kendraindexconfiguration.html>`__
    """

    props: PropsDictType = {
        "IndexId": (str, True),
    }


class NativeIndexConfiguration(AWSProperty):
    """
    `NativeIndexConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-retriever-nativeindexconfiguration.html>`__
    """

    props: PropsDictType = {
        "IndexId": (str, True),
    }


class RetrieverConfiguration(AWSProperty):
    """
    `RetrieverConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-retriever-retrieverconfiguration.html>`__
    """

    props: PropsDictType = {
        "KendraIndexConfiguration": (KendraIndexConfiguration, False),
        "NativeIndexConfiguration": (NativeIndexConfiguration, False),
    }


class Retriever(AWSObject):
    """
    `Retriever <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-retriever.html>`__
    """

    resource_type = "AWS::QBusiness::Retriever"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "Configuration": (RetrieverConfiguration, True),
        "DisplayName": (str, True),
        "RoleArn": (str, False),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class OpenIDConnectProviderConfiguration(AWSProperty):
    """
    `OpenIDConnectProviderConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-webexperience-openidconnectproviderconfiguration.html>`__
    """

    props: PropsDictType = {
        "SecretsArn": (str, True),
        "SecretsRole": (str, True),
    }


class SamlProviderConfiguration(AWSProperty):
    """
    `SamlProviderConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-webexperience-samlproviderconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthenticationUrl": (str, True),
    }


class IdentityProviderConfiguration(AWSProperty):
    """
    `IdentityProviderConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-webexperience-identityproviderconfiguration.html>`__
    """

    props: PropsDictType = {
        "OpenIDConnectConfiguration": (OpenIDConnectProviderConfiguration, False),
        "SamlConfiguration": (SamlProviderConfiguration, False),
    }


class WebExperience(AWSObject):
    """
    `WebExperience <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-qbusiness-webexperience.html>`__
    """

    resource_type = "AWS::QBusiness::WebExperience"

    props: PropsDictType = {
        "ApplicationId": (str, True),
        "IdentityProviderConfiguration": (IdentityProviderConfiguration, False),
        "RoleArn": (str, False),
        "SamplePromptsControlMode": (str, False),
        "Subtitle": (str, False),
        "Tags": (Tags, False),
        "Title": (str, False),
        "WelcomeMessage": (str, False),
    }


class TextDocumentStatistics(AWSProperty):
    """
    `TextDocumentStatistics <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-index-textdocumentstatistics.html>`__
    """

    props: PropsDictType = {
        "IndexedTextBytes": (double, False),
        "IndexedTextDocumentCount": (double, False),
    }


class IndexStatistics(AWSProperty):
    """
    `IndexStatistics <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-qbusiness-index-indexstatistics.html>`__
    """

    props: PropsDictType = {
        "TextDocumentStatistics": (TextDocumentStatistics, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators.codeartifact import policytypes


class Domain(AWSObject):
    """
    `Domain <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeartifact-domain.html>`__
    """

    resource_type = "AWS::CodeArtifact::Domain"

    props: PropsDictType = {
        "DomainName": (str, True),
        "EncryptionKey": (str, False),
        "PermissionsPolicyDocument": (policytypes, False),
        "Tags": (Tags, False),
    }


class RestrictionType(AWSProperty):
    """
    `RestrictionType <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeartifact-packagegroup-restrictiontype.html>`__
    """

    props: PropsDictType = {
        "Repositories": ([str], False),
        "RestrictionMode": (str, True),
    }


class Restrictions(AWSProperty):
    """
    `Restrictions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeartifact-packagegroup-restrictions.html>`__
    """

    props: PropsDictType = {
        "ExternalUpstream": (RestrictionType, False),
        "InternalUpstream": (RestrictionType, False),
        "Publish": (RestrictionType, False),
    }


class OriginConfiguration(AWSProperty):
    """
    `OriginConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeartifact-packagegroup-originconfiguration.html>`__
    """

    props: PropsDictType = {
        "Restrictions": (Restrictions, True),
    }


class PackageGroup(AWSObject):
    """
    `PackageGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeartifact-packagegroup.html>`__
    """

    resource_type = "AWS::CodeArtifact::PackageGroup"

    props: PropsDictType = {
        "ContactInfo": (str, False),
        "Description": (str, False),
        "DomainName": (str, True),
        "DomainOwner": (str, False),
        "OriginConfiguration": (OriginConfiguration, False),
        "Pattern": (str, True),
        "Tags": (Tags, False),
    }


class Repository(AWSObject):
    """
    `Repository <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeartifact-repository.html>`__
    """

    resource_type = "AWS::CodeArtifact::Repository"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainName": (str, True),
        "DomainOwner": (str, False),
        "ExternalConnections": ([str], False),
        "PermissionsPolicyDocument": (policytypes, False),
        "RepositoryName": (str, True),
        "Tags": (Tags, False),
        "Upstreams": ([str], False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean


class FilterExpression(AWSProperty):
    """
    `FilterExpression <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-filterexpression.html>`__
    """

    props: PropsDictType = {
        "Expression": (str, True),
        "Type": (str, True),
    }


class RelationalFilterConfiguration(AWSProperty):
    """
    `RelationalFilterConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-relationalfilterconfiguration.html>`__
    """

    props: PropsDictType = {
        "DatabaseName": (str, True),
        "FilterExpressions": ([FilterExpression], False),
        "SchemaName": (str, False),
    }


class GlueRunConfigurationInput(AWSProperty):
    """
    `GlueRunConfigurationInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-gluerunconfigurationinput.html>`__
    """

    props: PropsDictType = {
        "AutoImportDataQualityResult": (boolean, False),
        "DataAccessRole": (str, False),
        "RelationalFilterConfigurations": ([RelationalFilterConfiguration], True),
    }


class RedshiftCredentialConfiguration(AWSProperty):
    """
    `RedshiftCredentialConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftcredentialconfiguration.html>`__
    """

    props: PropsDictType = {
        "SecretManagerArn": (str, True),
    }


class RedshiftClusterStorage(AWSProperty):
    """
    `RedshiftClusterStorage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftclusterstorage.html>`__
    """

    props: PropsDictType = {
        "ClusterName": (str, True),
    }


class RedshiftServerlessStorage(AWSProperty):
    """
    `RedshiftServerlessStorage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftserverlessstorage.html>`__
    """

    props: PropsDictType = {
        "WorkgroupName": (str, True),
    }


class RedshiftStorage(AWSProperty):
    """
    `RedshiftStorage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftstorage.html>`__
    """

    props: PropsDictType = {
        "RedshiftClusterSource": (RedshiftClusterStorage, False),
        "RedshiftServerlessSource": (RedshiftServerlessStorage, False),
    }


class RedshiftRunConfigurationInput(AWSProperty):
    """
    `RedshiftRunConfigurationInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html>`__
    """

    props: PropsDictType = {
        "DataAccessRole": (str, False),
        "RedshiftCredentialConfiguration": (RedshiftCredentialConfiguration, True),
        "RedshiftStorage": (RedshiftStorage, True),
        "RelationalFilterConfigurations": ([RelationalFilterConfiguration], True),
    }


class DataSourceConfigurationInput(AWSProperty):
    """
    `DataSourceConfigurationInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-datasourceconfigurationinput.html>`__
    """

    props: PropsDictType = {
        "GlueRunConfiguration": (GlueRunConfigurationInput, False),
        "RedshiftRunConfiguration": (RedshiftRunConfigurationInput, False),
    }


class FormInput(AWSProperty):
    """
    `FormInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html>`__
    """

    props: PropsDictType = {
        "Content": (str, False),
        "FormName": (str, True),
        "TypeIdentifier": (str, False),
        "TypeRevision": (str, False),
    }


class RecommendationConfiguration(AWSProperty):
    """
    `RecommendationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-recommendationconfiguration.html>`__
    """

    props: PropsDictType = {
        "EnableBusinessNameGeneration": (boolean, False),
    }


class ScheduleConfiguration(AWSProperty):
    """
    `ScheduleConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-scheduleconfiguration.html>`__
    """

    props: PropsDictType = {
        "Schedule": (str, False),
        "Timezone": (str, False),
    }


class DataSource(AWSObject):
    """
    `DataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html>`__
    """

    resource_type = "AWS::DataZone::DataSource"

    props: PropsDictType = {
        "AssetFormsInput": ([FormInput], False),
        "Configuration": (DataSourceConfigurationInput, False),
        "Description": (str, False),
        "DomainIdentifier": (str, True),
        "EnableSetting": (str, False),
        "EnvironmentIdentifier": (str, True),
        "Name": (str, True),
        "ProjectIdentifier": (str, True),
        "PublishOnImport": (boolean, False),
        "Recommendation": (RecommendationConfiguration, False),
        "Schedule": (ScheduleConfiguration, False),
        "Type": (str, True),
    }


class SingleSignOn(AWSProperty):
    """
    `SingleSignOn <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-domain-singlesignon.html>`__
    """

    props: PropsDictType = {
        "Type": (str, False),
        "UserAssignment": (str, False),
    }


class Domain(AWSObject):
    """
    `Domain <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html>`__
    """

    resource_type = "AWS::DataZone::Domain"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainExecutionRole": (str, True),
        "KmsKeyIdentifier": (str, False),
        "Name": (str, True),
        "SingleSignOn": (SingleSignOn, False),
        "Tags": (Tags, False),
    }


class EnvironmentParameter(AWSProperty):
    """
    `EnvironmentParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentprofile-environmentparameter.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "Value": (str, False),
    }


class Environment(AWSObject):
    """
    `Environment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html>`__
    """

    resource_type = "AWS::DataZone::Environment"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainIdentifier": (str, True),
        "EnvironmentAccountIdentifier": (str, False),
        "EnvironmentAccountRegion": (str, False),
        "EnvironmentProfileIdentifier": (str, False),
        "EnvironmentRoleArn": (str, False),
        "GlossaryTerms": ([str], False),
        "Name": (str, True),
        "ProjectIdentifier": (str, True),
        "UserParameters": ([EnvironmentParameter], False),
    }


class AwsConsoleLinkParameters(AWSProperty):
    """
    `AwsConsoleLinkParameters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentactions-awsconsolelinkparameters.html>`__
    """

    props: PropsDictType = {
        "Uri": (str, False),
    }


class EnvironmentActions(AWSObject):
    """
    `EnvironmentActions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentactions.html>`__
    """

    resource_type = "AWS::DataZone::EnvironmentActions"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainIdentifier": (str, False),
        "EnvironmentIdentifier": (str, False),
        "Identifier": (str, False),
        "Name": (str, True),
        "Parameters": (AwsConsoleLinkParameters, False),
    }


class RegionalParameter(AWSProperty):
    """
    `RegionalParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentblueprintconfiguration-regionalparameter.html>`__
    """

    props: PropsDictType = {
        "Parameters": (dict, False),
        "Region": (str, False),
    }


class EnvironmentBlueprintConfiguration(AWSObject):
    """
    `EnvironmentBlueprintConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html>`__
    """

    resource_type = "AWS::DataZone::EnvironmentBlueprintConfiguration"

    props: PropsDictType = {
        "DomainIdentifier": (str, True),
        "EnabledRegions": ([str], True),
        "EnvironmentBlueprintIdentifier": (str, True),
        "ManageAccessRoleArn": (str, False),
        "ProvisioningRoleArn": (str, False),
        "RegionalParameters": ([RegionalParameter], False),
    }


class EnvironmentProfile(AWSObject):
    """
    `EnvironmentProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html>`__
    """

    resource_type = "AWS::DataZone::EnvironmentProfile"

    props: PropsDictType = {
        "AwsAccountId": (str, True),
        "AwsAccountRegion": (str, True),
        "Description": (str, False),
        "DomainIdentifier": (str, True),
        "EnvironmentBlueprintIdentifier": (str, True),
        "Name": (str, True),
        "ProjectIdentifier": (str, True),
        "UserParameters": ([EnvironmentParameter], False),
    }


class GroupProfile(AWSObject):
    """
    `GroupProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-groupprofile.html>`__
    """

    resource_type = "AWS::DataZone::GroupProfile"

    props: PropsDictType = {
        "DomainIdentifier": (str, True),
        "GroupIdentifier": (str, True),
        "Status": (str, False),
    }


class Project(AWSObject):
    """
    `Project <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html>`__
    """

    resource_type = "AWS::DataZone::Project"

    props: PropsDictType = {
        "Description": (str, False),
        "DomainIdentifier": (str, True),
        "GlossaryTerms": ([str], False),
        "Name": (str, True),
    }


class Member(AWSProperty):
    """
    `Member <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-projectmembership-member.html>`__
    """

    props: PropsDictType = {
        "GroupIdentifier": (str, False),
        "UserIdentifier": (str, False),
    }


class ProjectMembership(AWSObject):
    """
    `ProjectMembership <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-projectmembership.html>`__
    """

    resource_type = "AWS::DataZone::ProjectMembership"

    props: PropsDictType = {
        "Designation": (str, True),
        "DomainIdentifier": (str, True),
        "Member": (Member, True),
        "ProjectIdentifier": (str, True),
    }


class SubscriptionTargetForm(AWSProperty):
    """
    `SubscriptionTargetForm <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-subscriptiontarget-subscriptiontargetform.html>`__
    """

    props: PropsDictType = {
        "Content": (str, True),
        "FormName": (str, True),
    }


class SubscriptionTarget(AWSObject):
    """
    `SubscriptionTarget <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html>`__
    """

    resource_type = "AWS::DataZone::SubscriptionTarget"

    props: PropsDictType = {
        "ApplicableAssetTypes": ([str], True),
        "AuthorizedPrincipals": ([str], True),
        "DomainIdentifier": (str, True),
        "EnvironmentIdentifier": (str, True),
        "ManageAccessRole": (str, True),
        "Name": (str, True),
        "Provider": (str, False),
        "SubscriptionTargetConfig": ([SubscriptionTargetForm], True),
        "Type": (str, True),
    }


class UserProfile(AWSObject):
    """
    `UserProfile <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-userprofile.html>`__
    """

    resource_type = "AWS::DataZone::UserProfile"

    props: PropsDictType = {
        "DomainIdentifier": (str, True),
        "Status": (str, False),
        "UserIdentifier": (str, True),
        "UserType": (str, False),
    }


class IamUserProfileDetails(AWSProperty):
    """
    `IamUserProfileDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-userprofile-iamuserprofiledetails.html>`__
    """

    props: PropsDictType = {
        "Arn": (str, False),
    }


class SsoUserProfileDetails(AWSProperty):
    """
    `SsoUserProfileDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-userprofile-ssouserprofiledetails.html>`__
    """

    props: PropsDictType = {
        "FirstName": (str, False),
        "LastName": (str, False),
        "Username": (str, False),
    }


class UserProfileDetails(AWSProperty):
    """
    `UserProfileDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-userprofile-userprofiledetails.html>`__
    """

    props: PropsDictType = {
        "Iam": (IamUserProfileDetails, False),
        "Sso": (SsoUserProfileDetails, False),
    }



import io
import os
import re
import sys


def test_example(input_filename, expected_output):
    saved = sys.stdout
    stdout = io.StringIO()
    try:
        sys.stdout = stdout
        with open(input_filename) as f:
            code = compile(f.read(), input_filename, "exec")
            exec(code, {"__name__": "__main__"})
    finally:
        sys.stdout = saved
    # rewind fake stdout so we can read it
    stdout.seek(0)
    actual_output = stdout.read()
    assert str(expected_output) == str(actual_output)


def load_example_tests():
    # Filter out all *.py files from the examples directory
    examples = "examples"
    regex = re.compile(r".py$", re.I)
    example_filenames = filter(regex.search, os.listdir(examples))

    results = []
    for f in example_filenames:
        expected_output = open("tests/examples_output/%s.template" % f[:-3]).read()
        results.append((examples + "/" + f, expected_output))

    return results


def pytest_generate_tests(metafunc):
    example_data = load_example_tests()
    metafunc.parametrize("input_filename,expected_output", example_data)



import unittest

from troposphere import GetAtt, If, Sub, Tag, Tags
from troposphere.autoscaling import Tags as ASTags


class TestTags(unittest.TestCase):
    def test_TagAddition(self):
        tags = Tags(foo="foo")
        tags += Tags(bar="bar")
        tags = tags + Tags(baz="baz")
        result = [
            {"Value": "foo", "Key": "foo"},
            {"Value": "bar", "Key": "bar"},
            {"Value": "baz", "Key": "baz"},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_TagConditional(self):
        tags = Tags(
            {"foo": "foo"}, If("MyCondition", Tag("bar", "bar"), Tag("baz", "baz"))
        )
        result = [
            {
                "Fn::If": [
                    "MyCondition",
                    {"Key": "bar", "Value": "bar"},
                    {"Key": "baz", "Value": "baz"},
                ]
            },
            {"Value": "foo", "Key": "foo"},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_ASTagAddition(self):
        tags = ASTags(foo=("fooval", True))
        tags += ASTags(bar=("barval", False))
        tags = tags + ASTags(baz="bazval")
        result = [
            {"Value": "fooval", "Key": "foo", "PropagateAtLaunch": True},
            {"Value": "barval", "Key": "bar", "PropagateAtLaunch": False},
            {"Value": "bazval", "Key": "baz", "PropagateAtLaunch": True},
        ]
        self.assertEqual(tags.to_dict(), result)

    def test_Unsortable(self):
        result = [{"Key": {"Fn::Sub": "somestring"}, "Value": "val"}]
        tags = Tags({Sub("somestring"): "val"})
        self.assertEqual(tags.to_dict(), result)

    def test_Formats(self):
        result = [
            {"Value": "bar", "Key": "bar"},
            {"Value": "baz", "Key": "baz"},
            {"Value": "foo", "Key": "foo"},
        ]
        tags = Tags(bar="bar", baz="baz", foo="foo")
        self.assertEqual(tags.to_dict(), result)
        tags = Tags({"bar": "bar", "baz": "baz", "foo": "foo"})
        self.assertEqual(tags.to_dict(), result)
        tags = Tags(**{"bar": "bar", "baz": "baz", "foo": "foo"})
        self.assertEqual(tags.to_dict(), result)
        result = [{"Key": "test-tag", "Value": "123456"}]
        tags = Tags({"test-tag": "123456"})
        self.assertEqual(tags.to_dict(), result)

        with self.assertRaises(TypeError):
            Tags(1)
        with self.assertRaises(TypeError):
            Tags("tag")
        with self.assertRaises(TypeError):
            Tags("key", "value")
        with self.assertRaises(TypeError):
            Tags({}, "key", "value")

    def test_json_tags(self):
        from troposphere.batch import ContainerProperties, JobDefinition

        JobDefinition(
            "myjobdef",
            Type="container",
            ContainerProperties=ContainerProperties(
                Image="image",
                Vcpus=2,
                Memory=2000,
                Command=["echo", "foobar"],
            ),
            Tags={"foo": "bar"},
        )

        JobDefinition(
            "myjobdef",
            Type="container",
            ContainerProperties=ContainerProperties(
                Image="image",
                Vcpus=2,
                Memory=2000,
                Command=["echo", "foobar"],
            ),
            Tags=GetAtt("resource", "tags"),
        )

        with self.assertRaises(TypeError):
            JobDefinition(
                "myjobdef",
                Type="container",
                ContainerProperties=ContainerProperties(
                    Image="image",
                    Vcpus=2,
                    Memory=2000,
                    Command=["echo", "foobar"],
                ),
                Tags=Tags({"foo": "bar"}),
            )

        with self.assertRaises(TypeError):
            JobDefinition(
                "myjobdef",
                Type="container",
                ContainerProperties=ContainerProperties(
                    Image="image",
                    Vcpus=2,
                    Memory=2000,
                    Command=["echo", "foobar"],
                ),
                Tags="string",
            )

    def test_object_tags(self):
        from troposphere.dynamodb import KeySchema, Table

        Table(
            "mytable",
            KeySchema=[KeySchema(KeyType="HASH", AttributeName="id")],
            BillingMode="PAY_PER_REQUEST",
            Tags=Tags(Name="Example"),
        )

        Table(
            "mytable",
            KeySchema=[KeySchema(KeyType="HASH", AttributeName="id")],
            BillingMode="PAY_PER_REQUEST",
            Tags=GetAtt("resource", "tags"),
        )

        with self.assertRaises(TypeError):
            Table(
                "mytable",
                KeySchema=[KeySchema(KeyType="HASH", AttributeName="id")],
                BillingMode="PAY_PER_REQUEST",
                Tags={"Name": "Example"},
            )

        with self.assertRaises(TypeError):
            Table(
                "mytable",
                KeySchema=[KeySchema(KeyType="HASH", AttributeName="id")],
                BillingMode="PAY_PER_REQUEST",
                Tags="string",
            )


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags


class Hypervisor(AWSObject):
    """
    `Hypervisor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-backupgateway-hypervisor.html>`__
    """

    resource_type = "AWS::BackupGateway::Hypervisor"

    props: PropsDictType = {
        "Host": (str, False),
        "KmsKeyArn": (str, False),
        "LogGroupArn": (str, False),
        "Name": (str, False),
        "Password": (str, False),
        "Tags": (Tags, False),
        "Username": (str, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer


class S3Identifier(AWSProperty):
    """
    `S3Identifier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-s3identifier.html>`__
    """

    props: PropsDictType = {
        "S3BucketName": (str, False),
        "S3ObjectKey": (str, False),
    }


class APISchema(AWSProperty):
    """
    `APISchema <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-apischema.html>`__
    """

    props: PropsDictType = {
        "Payload": (str, False),
        "S3": (S3Identifier, False),
    }


class ActionGroupExecutor(AWSProperty):
    """
    `ActionGroupExecutor <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-actiongroupexecutor.html>`__
    """

    props: PropsDictType = {
        "CustomControl": (str, False),
        "Lambda": (str, False),
    }


class ParameterDetail(AWSProperty):
    """
    `ParameterDetail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-parameterdetail.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "Required": (boolean, False),
        "Type": (str, True),
    }


class Function(AWSProperty):
    """
    `Function <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-function.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "Parameters": (dict, False),
    }


class FunctionSchema(AWSProperty):
    """
    `FunctionSchema <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-functionschema.html>`__
    """

    props: PropsDictType = {
        "Functions": ([Function], True),
    }


class AgentActionGroup(AWSProperty):
    """
    `AgentActionGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-agentactiongroup.html>`__
    """

    props: PropsDictType = {
        "ActionGroupExecutor": (ActionGroupExecutor, False),
        "ActionGroupName": (str, True),
        "ActionGroupState": (str, False),
        "ApiSchema": (APISchema, False),
        "Description": (str, False),
        "FunctionSchema": (FunctionSchema, False),
        "ParentActionGroupSignature": (str, False),
        "SkipResourceInUseCheckOnDelete": (boolean, False),
    }


class AgentKnowledgeBase(AWSProperty):
    """
    `AgentKnowledgeBase <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-agentknowledgebase.html>`__
    """

    props: PropsDictType = {
        "Description": (str, True),
        "KnowledgeBaseId": (str, True),
        "KnowledgeBaseState": (str, False),
    }


class GuardrailConfiguration(AWSProperty):
    """
    `GuardrailConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-guardrailconfiguration.html>`__
    """

    props: PropsDictType = {
        "GuardrailIdentifier": (str, False),
        "GuardrailVersion": (str, False),
    }


class InferenceConfiguration(AWSProperty):
    """
    `InferenceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-inferenceconfiguration.html>`__
    """

    props: PropsDictType = {
        "MaximumLength": (double, False),
        "StopSequences": ([str], False),
        "Temperature": (double, False),
        "TopK": (double, False),
        "TopP": (double, False),
    }


class PromptConfiguration(AWSProperty):
    """
    `PromptConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-promptconfiguration.html>`__
    """

    props: PropsDictType = {
        "BasePromptTemplate": (str, False),
        "InferenceConfiguration": (InferenceConfiguration, False),
        "ParserMode": (str, False),
        "PromptCreationMode": (str, False),
        "PromptState": (str, False),
        "PromptType": (str, False),
    }


class PromptOverrideConfiguration(AWSProperty):
    """
    `PromptOverrideConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agent-promptoverrideconfiguration.html>`__
    """

    props: PropsDictType = {
        "OverrideLambda": (str, False),
        "PromptConfigurations": ([PromptConfiguration], True),
    }


class Agent(AWSObject):
    """
    `Agent <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-agent.html>`__
    """

    resource_type = "AWS::Bedrock::Agent"

    props: PropsDictType = {
        "ActionGroups": ([AgentActionGroup], False),
        "AgentName": (str, True),
        "AgentResourceRoleArn": (str, False),
        "AutoPrepare": (boolean, False),
        "CustomerEncryptionKeyArn": (str, False),
        "Description": (str, False),
        "FoundationModel": (str, False),
        "GuardrailConfiguration": (GuardrailConfiguration, False),
        "IdleSessionTTLInSeconds": (double, False),
        "Instruction": (str, False),
        "KnowledgeBases": ([AgentKnowledgeBase], False),
        "PromptOverrideConfiguration": (PromptOverrideConfiguration, False),
        "SkipResourceInUseCheckOnDelete": (boolean, False),
        "Tags": (dict, False),
        "TestAliasTags": (dict, False),
    }


class AgentAliasRoutingConfigurationListItem(AWSProperty):
    """
    `AgentAliasRoutingConfigurationListItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agentalias-agentaliasroutingconfigurationlistitem.html>`__
    """

    props: PropsDictType = {
        "AgentVersion": (str, True),
    }


class AgentAlias(AWSObject):
    """
    `AgentAlias <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-agentalias.html>`__
    """

    resource_type = "AWS::Bedrock::AgentAlias"

    props: PropsDictType = {
        "AgentAliasName": (str, True),
        "AgentId": (str, True),
        "Description": (str, False),
        "RoutingConfiguration": ([AgentAliasRoutingConfigurationListItem], False),
        "Tags": (dict, False),
    }


class PatternObjectFilter(AWSProperty):
    """
    `PatternObjectFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-patternobjectfilter.html>`__
    """

    props: PropsDictType = {
        "ExclusionFilters": ([str], False),
        "InclusionFilters": ([str], False),
        "ObjectType": (str, True),
    }


class PatternObjectFilterConfiguration(AWSProperty):
    """
    `PatternObjectFilterConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-patternobjectfilterconfiguration.html>`__
    """

    props: PropsDictType = {
        "Filters": ([PatternObjectFilter], True),
    }


class CrawlFilterConfiguration(AWSProperty):
    """
    `CrawlFilterConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-crawlfilterconfiguration.html>`__
    """

    props: PropsDictType = {
        "PatternObjectFilter": (PatternObjectFilterConfiguration, False),
        "Type": (str, True),
    }


class ConfluenceCrawlerConfiguration(AWSProperty):
    """
    `ConfluenceCrawlerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-confluencecrawlerconfiguration.html>`__
    """

    props: PropsDictType = {
        "FilterConfiguration": (CrawlFilterConfiguration, False),
    }


class ConfluenceSourceConfiguration(AWSProperty):
    """
    `ConfluenceSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-confluencesourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthType": (str, True),
        "CredentialsSecretArn": (str, True),
        "HostType": (str, True),
        "HostUrl": (str, True),
    }


class ConfluenceDataSourceConfiguration(AWSProperty):
    """
    `ConfluenceDataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-confluencedatasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlerConfiguration": (ConfluenceCrawlerConfiguration, False),
        "SourceConfiguration": (ConfluenceSourceConfiguration, True),
    }


class S3DataSourceConfiguration(AWSProperty):
    """
    `S3DataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-s3datasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "BucketArn": (str, True),
        "BucketOwnerAccountId": (str, False),
        "InclusionPrefixes": ([str], False),
    }


class SalesforceCrawlerConfiguration(AWSProperty):
    """
    `SalesforceCrawlerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-salesforcecrawlerconfiguration.html>`__
    """

    props: PropsDictType = {
        "FilterConfiguration": (CrawlFilterConfiguration, False),
    }


class SalesforceSourceConfiguration(AWSProperty):
    """
    `SalesforceSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-salesforcesourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthType": (str, True),
        "CredentialsSecretArn": (str, True),
        "HostUrl": (str, True),
    }


class SalesforceDataSourceConfiguration(AWSProperty):
    """
    `SalesforceDataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-salesforcedatasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlerConfiguration": (SalesforceCrawlerConfiguration, False),
        "SourceConfiguration": (SalesforceSourceConfiguration, True),
    }


class SharePointCrawlerConfiguration(AWSProperty):
    """
    `SharePointCrawlerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-sharepointcrawlerconfiguration.html>`__
    """

    props: PropsDictType = {
        "FilterConfiguration": (CrawlFilterConfiguration, False),
    }


class SharePointSourceConfiguration(AWSProperty):
    """
    `SharePointSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-sharepointsourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthType": (str, True),
        "CredentialsSecretArn": (str, True),
        "Domain": (str, True),
        "HostType": (str, True),
        "SiteUrls": ([str], True),
        "TenantId": (str, False),
    }


class SharePointDataSourceConfiguration(AWSProperty):
    """
    `SharePointDataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-sharepointdatasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlerConfiguration": (SharePointCrawlerConfiguration, False),
        "SourceConfiguration": (SharePointSourceConfiguration, True),
    }


class WebCrawlerLimits(AWSProperty):
    """
    `WebCrawlerLimits <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-webcrawlerlimits.html>`__
    """

    props: PropsDictType = {
        "RateLimit": (integer, False),
    }


class WebCrawlerConfiguration(AWSProperty):
    """
    `WebCrawlerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-webcrawlerconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlerLimits": (WebCrawlerLimits, False),
        "ExclusionFilters": ([str], False),
        "InclusionFilters": ([str], False),
        "Scope": (str, False),
    }


class SeedUrl(AWSProperty):
    """
    `SeedUrl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-seedurl.html>`__
    """

    props: PropsDictType = {
        "Url": (str, True),
    }


class UrlConfiguration(AWSProperty):
    """
    `UrlConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-urlconfiguration.html>`__
    """

    props: PropsDictType = {
        "SeedUrls": ([SeedUrl], True),
    }


class WebSourceConfiguration(AWSProperty):
    """
    `WebSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-websourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "UrlConfiguration": (UrlConfiguration, True),
    }


class WebDataSourceConfiguration(AWSProperty):
    """
    `WebDataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-webdatasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlerConfiguration": (WebCrawlerConfiguration, False),
        "SourceConfiguration": (WebSourceConfiguration, True),
    }


class DataSourceConfiguration(AWSProperty):
    """
    `DataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-datasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "ConfluenceConfiguration": (ConfluenceDataSourceConfiguration, False),
        "S3Configuration": (S3DataSourceConfiguration, False),
        "SalesforceConfiguration": (SalesforceDataSourceConfiguration, False),
        "SharePointConfiguration": (SharePointDataSourceConfiguration, False),
        "Type": (str, True),
        "WebConfiguration": (WebDataSourceConfiguration, False),
    }


class ServerSideEncryptionConfiguration(AWSProperty):
    """
    `ServerSideEncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-serversideencryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KmsKeyArn": (str, False),
    }


class FixedSizeChunkingConfiguration(AWSProperty):
    """
    `FixedSizeChunkingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-fixedsizechunkingconfiguration.html>`__
    """

    props: PropsDictType = {
        "MaxTokens": (integer, True),
        "OverlapPercentage": (integer, True),
    }


class HierarchicalChunkingLevelConfiguration(AWSProperty):
    """
    `HierarchicalChunkingLevelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-hierarchicalchunkinglevelconfiguration.html>`__
    """

    props: PropsDictType = {
        "MaxTokens": (integer, True),
    }


class HierarchicalChunkingConfiguration(AWSProperty):
    """
    `HierarchicalChunkingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-hierarchicalchunkingconfiguration.html>`__
    """

    props: PropsDictType = {
        "LevelConfigurations": ([HierarchicalChunkingLevelConfiguration], True),
        "OverlapTokens": (integer, True),
    }


class SemanticChunkingConfiguration(AWSProperty):
    """
    `SemanticChunkingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-semanticchunkingconfiguration.html>`__
    """

    props: PropsDictType = {
        "BreakpointPercentileThreshold": (integer, True),
        "BufferSize": (integer, True),
        "MaxTokens": (integer, True),
    }


class ChunkingConfiguration(AWSProperty):
    """
    `ChunkingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-chunkingconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChunkingStrategy": (str, True),
        "FixedSizeChunkingConfiguration": (FixedSizeChunkingConfiguration, False),
        "HierarchicalChunkingConfiguration": (HierarchicalChunkingConfiguration, False),
        "SemanticChunkingConfiguration": (SemanticChunkingConfiguration, False),
    }


class S3Location(AWSProperty):
    """
    `S3Location <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flow-s3location.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, True),
        "Key": (str, True),
        "Version": (str, False),
    }


class IntermediateStorage(AWSProperty):
    """
    `IntermediateStorage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-intermediatestorage.html>`__
    """

    props: PropsDictType = {
        "S3Location": (S3Location, True),
    }


class TransformationLambdaConfiguration(AWSProperty):
    """
    `TransformationLambdaConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-transformationlambdaconfiguration.html>`__
    """

    props: PropsDictType = {
        "LambdaArn": (str, True),
    }


class TransformationFunction(AWSProperty):
    """
    `TransformationFunction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-transformationfunction.html>`__
    """

    props: PropsDictType = {
        "TransformationLambdaConfiguration": (TransformationLambdaConfiguration, True),
    }


class Transformation(AWSProperty):
    """
    `Transformation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-transformation.html>`__
    """

    props: PropsDictType = {
        "StepToApply": (str, True),
        "TransformationFunction": (TransformationFunction, True),
    }


class CustomTransformationConfiguration(AWSProperty):
    """
    `CustomTransformationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-customtransformationconfiguration.html>`__
    """

    props: PropsDictType = {
        "IntermediateStorage": (IntermediateStorage, True),
        "Transformations": ([Transformation], True),
    }


class ParsingPrompt(AWSProperty):
    """
    `ParsingPrompt <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-parsingprompt.html>`__
    """

    props: PropsDictType = {
        "ParsingPromptText": (str, True),
    }


class BedrockFoundationModelConfiguration(AWSProperty):
    """
    `BedrockFoundationModelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-bedrockfoundationmodelconfiguration.html>`__
    """

    props: PropsDictType = {
        "ModelArn": (str, True),
        "ParsingPrompt": (ParsingPrompt, False),
    }


class ParsingConfiguration(AWSProperty):
    """
    `ParsingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-parsingconfiguration.html>`__
    """

    props: PropsDictType = {
        "BedrockFoundationModelConfiguration": (
            BedrockFoundationModelConfiguration,
            False,
        ),
        "ParsingStrategy": (str, True),
    }


class VectorIngestionConfiguration(AWSProperty):
    """
    `VectorIngestionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-datasource-vectoringestionconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChunkingConfiguration": (ChunkingConfiguration, False),
        "CustomTransformationConfiguration": (CustomTransformationConfiguration, False),
        "ParsingConfiguration": (ParsingConfiguration, False),
    }


class DataSource(AWSObject):
    """
    `DataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-datasource.html>`__
    """

    resource_type = "AWS::Bedrock::DataSource"

    props: PropsDictType = {
        "DataDeletionPolicy": (str, False),
        "DataSourceConfiguration": (DataSourceConfiguration, True),
        "Description": (str, False),
        "KnowledgeBaseId": (str, True),
        "Name": (str, True),
        "ServerSideEncryptionConfiguration": (ServerSideEncryptionConfiguration, False),
        "VectorIngestionConfiguration": (VectorIngestionConfiguration, False),
    }


class FlowConditionalConnectionConfiguration(AWSProperty):
    """
    `FlowConditionalConnectionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowconditionalconnectionconfiguration.html>`__
    """

    props: PropsDictType = {
        "Condition": (str, True),
    }


class FlowDataConnectionConfiguration(AWSProperty):
    """
    `FlowDataConnectionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowdataconnectionconfiguration.html>`__
    """

    props: PropsDictType = {
        "SourceOutput": (str, True),
        "TargetInput": (str, True),
    }


class FlowConnectionConfiguration(AWSProperty):
    """
    `FlowConnectionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowconnectionconfiguration.html>`__
    """

    props: PropsDictType = {
        "Conditional": (FlowConditionalConnectionConfiguration, False),
        "Data": (FlowDataConnectionConfiguration, False),
    }


class FlowConnection(AWSProperty):
    """
    `FlowConnection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowconnection.html>`__
    """

    props: PropsDictType = {
        "Configuration": (FlowConnectionConfiguration, False),
        "Name": (str, True),
        "Source": (str, True),
        "Target": (str, True),
        "Type": (str, True),
    }


class AgentFlowNodeConfiguration(AWSProperty):
    """
    `AgentFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-agentflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "AgentAliasArn": (str, True),
    }


class FlowCondition(AWSProperty):
    """
    `FlowCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowcondition.html>`__
    """

    props: PropsDictType = {
        "Expression": (str, False),
        "Name": (str, True),
    }


class ConditionFlowNodeConfiguration(AWSProperty):
    """
    `ConditionFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-conditionflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "Conditions": ([FlowCondition], True),
    }


class KnowledgeBaseFlowNodeConfiguration(AWSProperty):
    """
    `KnowledgeBaseFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-knowledgebaseflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "KnowledgeBaseId": (str, True),
        "ModelId": (str, False),
    }


class LambdaFunctionFlowNodeConfiguration(AWSProperty):
    """
    `LambdaFunctionFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-lambdafunctionflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "LambdaArn": (str, True),
    }


class LexFlowNodeConfiguration(AWSProperty):
    """
    `LexFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-lexflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "BotAliasArn": (str, True),
        "LocaleId": (str, True),
    }


class PromptModelInferenceConfiguration(AWSProperty):
    """
    `PromptModelInferenceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-promptmodelinferenceconfiguration.html>`__
    """

    props: PropsDictType = {
        "MaxTokens": (double, False),
        "StopSequences": ([str], False),
        "Temperature": (double, False),
        "TopK": (double, False),
        "TopP": (double, False),
    }


class PromptInferenceConfiguration(AWSProperty):
    """
    `PromptInferenceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-promptinferenceconfiguration.html>`__
    """

    props: PropsDictType = {
        "Text": (PromptModelInferenceConfiguration, True),
    }


class PromptInputVariable(AWSProperty):
    """
    `PromptInputVariable <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-promptinputvariable.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
    }


class TextPromptTemplateConfiguration(AWSProperty):
    """
    `TextPromptTemplateConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-textprompttemplateconfiguration.html>`__
    """

    props: PropsDictType = {
        "InputVariables": ([PromptInputVariable], False),
        "Text": (str, True),
    }


class PromptTemplateConfiguration(AWSProperty):
    """
    `PromptTemplateConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-prompttemplateconfiguration.html>`__
    """

    props: PropsDictType = {
        "Text": (TextPromptTemplateConfiguration, True),
    }


class PromptFlowNodeInlineConfiguration(AWSProperty):
    """
    `PromptFlowNodeInlineConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-promptflownodeinlineconfiguration.html>`__
    """

    props: PropsDictType = {
        "InferenceConfiguration": (PromptInferenceConfiguration, False),
        "ModelId": (str, True),
        "TemplateConfiguration": (PromptTemplateConfiguration, True),
        "TemplateType": (str, True),
    }


class PromptFlowNodeResourceConfiguration(AWSProperty):
    """
    `PromptFlowNodeResourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-promptflownoderesourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "PromptArn": (str, True),
    }


class PromptFlowNodeSourceConfiguration(AWSProperty):
    """
    `PromptFlowNodeSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-promptflownodesourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "Inline": (PromptFlowNodeInlineConfiguration, False),
        "Resource": (PromptFlowNodeResourceConfiguration, False),
    }


class PromptFlowNodeConfiguration(AWSProperty):
    """
    `PromptFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-promptflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "SourceConfiguration": (PromptFlowNodeSourceConfiguration, True),
    }


class RetrievalFlowNodeS3Configuration(AWSProperty):
    """
    `RetrievalFlowNodeS3Configuration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-retrievalflownodes3configuration.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
    }


class RetrievalFlowNodeServiceConfiguration(AWSProperty):
    """
    `RetrievalFlowNodeServiceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-retrievalflownodeserviceconfiguration.html>`__
    """

    props: PropsDictType = {
        "S3": (RetrievalFlowNodeS3Configuration, False),
    }


class RetrievalFlowNodeConfiguration(AWSProperty):
    """
    `RetrievalFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-retrievalflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "ServiceConfiguration": (RetrievalFlowNodeServiceConfiguration, True),
    }


class StorageFlowNodeS3Configuration(AWSProperty):
    """
    `StorageFlowNodeS3Configuration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-storageflownodes3configuration.html>`__
    """

    props: PropsDictType = {
        "BucketName": (str, True),
    }


class StorageFlowNodeServiceConfiguration(AWSProperty):
    """
    `StorageFlowNodeServiceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-storageflownodeserviceconfiguration.html>`__
    """

    props: PropsDictType = {
        "S3": (StorageFlowNodeS3Configuration, False),
    }


class StorageFlowNodeConfiguration(AWSProperty):
    """
    `StorageFlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-storageflownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "ServiceConfiguration": (StorageFlowNodeServiceConfiguration, True),
    }


class FlowNodeConfiguration(AWSProperty):
    """
    `FlowNodeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flownodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "Agent": (AgentFlowNodeConfiguration, False),
        "Collector": (dict, False),
        "Condition": (ConditionFlowNodeConfiguration, False),
        "Input": (dict, False),
        "Iterator": (dict, False),
        "KnowledgeBase": (KnowledgeBaseFlowNodeConfiguration, False),
        "LambdaFunction": (LambdaFunctionFlowNodeConfiguration, False),
        "Lex": (LexFlowNodeConfiguration, False),
        "Output": (dict, False),
        "Prompt": (PromptFlowNodeConfiguration, False),
        "Retrieval": (RetrievalFlowNodeConfiguration, False),
        "Storage": (StorageFlowNodeConfiguration, False),
    }


class FlowNodeInput(AWSProperty):
    """
    `FlowNodeInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flownodeinput.html>`__
    """

    props: PropsDictType = {
        "Expression": (str, True),
        "Name": (str, True),
        "Type": (str, True),
    }


class FlowNodeOutput(AWSProperty):
    """
    `FlowNodeOutput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flownodeoutput.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Type": (str, True),
    }


class FlowNode(AWSProperty):
    """
    `FlowNode <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flownode.html>`__
    """

    props: PropsDictType = {
        "Configuration": (FlowNodeConfiguration, False),
        "Inputs": ([FlowNodeInput], False),
        "Name": (str, True),
        "Outputs": ([FlowNodeOutput], False),
        "Type": (str, True),
    }


class FlowDefinition(AWSProperty):
    """
    `FlowDefinition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowversion-flowdefinition.html>`__
    """

    props: PropsDictType = {
        "Connections": ([FlowConnection], False),
        "Nodes": ([FlowNode], False),
    }


class Flow(AWSObject):
    """
    `Flow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-flow.html>`__
    """

    resource_type = "AWS::Bedrock::Flow"

    props: PropsDictType = {
        "CustomerEncryptionKeyArn": (str, False),
        "Definition": (FlowDefinition, False),
        "DefinitionS3Location": (S3Location, False),
        "DefinitionString": (str, False),
        "DefinitionSubstitutions": (dict, False),
        "Description": (str, False),
        "ExecutionRoleArn": (str, True),
        "Name": (str, True),
        "Tags": (dict, False),
        "TestAliasTags": (dict, False),
    }


class FlowAliasRoutingConfigurationListItem(AWSProperty):
    """
    `FlowAliasRoutingConfigurationListItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flowalias-flowaliasroutingconfigurationlistitem.html>`__
    """

    props: PropsDictType = {
        "FlowVersion": (str, False),
    }


class FlowAlias(AWSObject):
    """
    `FlowAlias <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-flowalias.html>`__
    """

    resource_type = "AWS::Bedrock::FlowAlias"

    props: PropsDictType = {
        "Description": (str, False),
        "FlowArn": (str, True),
        "Name": (str, True),
        "RoutingConfiguration": ([FlowAliasRoutingConfigurationListItem], True),
        "Tags": (dict, False),
    }


class FlowVersion(AWSObject):
    """
    `FlowVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-flowversion.html>`__
    """

    resource_type = "AWS::Bedrock::FlowVersion"

    props: PropsDictType = {
        "Description": (str, False),
        "FlowArn": (str, True),
    }


class ContentFilterConfig(AWSProperty):
    """
    `ContentFilterConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-contentfilterconfig.html>`__
    """

    props: PropsDictType = {
        "InputStrength": (str, True),
        "OutputStrength": (str, True),
        "Type": (str, True),
    }


class ContentPolicyConfig(AWSProperty):
    """
    `ContentPolicyConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-contentpolicyconfig.html>`__
    """

    props: PropsDictType = {
        "FiltersConfig": ([ContentFilterConfig], True),
    }


class ContextualGroundingFilterConfig(AWSProperty):
    """
    `ContextualGroundingFilterConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-contextualgroundingfilterconfig.html>`__
    """

    props: PropsDictType = {
        "Threshold": (double, True),
        "Type": (str, True),
    }


class ContextualGroundingPolicyConfig(AWSProperty):
    """
    `ContextualGroundingPolicyConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-contextualgroundingpolicyconfig.html>`__
    """

    props: PropsDictType = {
        "FiltersConfig": ([ContextualGroundingFilterConfig], True),
    }


class PiiEntityConfig(AWSProperty):
    """
    `PiiEntityConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-piientityconfig.html>`__
    """

    props: PropsDictType = {
        "Action": (str, True),
        "Type": (str, True),
    }


class RegexConfig(AWSProperty):
    """
    `RegexConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-regexconfig.html>`__
    """

    props: PropsDictType = {
        "Action": (str, True),
        "Description": (str, False),
        "Name": (str, True),
        "Pattern": (str, True),
    }


class SensitiveInformationPolicyConfig(AWSProperty):
    """
    `SensitiveInformationPolicyConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-sensitiveinformationpolicyconfig.html>`__
    """

    props: PropsDictType = {
        "PiiEntitiesConfig": ([PiiEntityConfig], False),
        "RegexesConfig": ([RegexConfig], False),
    }


class TopicConfig(AWSProperty):
    """
    `TopicConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-topicconfig.html>`__
    """

    props: PropsDictType = {
        "Definition": (str, True),
        "Examples": ([str], False),
        "Name": (str, True),
        "Type": (str, True),
    }


class TopicPolicyConfig(AWSProperty):
    """
    `TopicPolicyConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-topicpolicyconfig.html>`__
    """

    props: PropsDictType = {
        "TopicsConfig": ([TopicConfig], True),
    }


class ManagedWordsConfig(AWSProperty):
    """
    `ManagedWordsConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-managedwordsconfig.html>`__
    """

    props: PropsDictType = {
        "Type": (str, True),
    }


class WordConfig(AWSProperty):
    """
    `WordConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-wordconfig.html>`__
    """

    props: PropsDictType = {
        "Text": (str, True),
    }


class WordPolicyConfig(AWSProperty):
    """
    `WordPolicyConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-guardrail-wordpolicyconfig.html>`__
    """

    props: PropsDictType = {
        "ManagedWordListsConfig": ([ManagedWordsConfig], False),
        "WordsConfig": ([WordConfig], False),
    }


class Guardrail(AWSObject):
    """
    `Guardrail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-guardrail.html>`__
    """

    resource_type = "AWS::Bedrock::Guardrail"

    props: PropsDictType = {
        "BlockedInputMessaging": (str, True),
        "BlockedOutputsMessaging": (str, True),
        "ContentPolicyConfig": (ContentPolicyConfig, False),
        "ContextualGroundingPolicyConfig": (ContextualGroundingPolicyConfig, False),
        "Description": (str, False),
        "KmsKeyArn": (str, False),
        "Name": (str, True),
        "SensitiveInformationPolicyConfig": (SensitiveInformationPolicyConfig, False),
        "Tags": (Tags, False),
        "TopicPolicyConfig": (TopicPolicyConfig, False),
        "WordPolicyConfig": (WordPolicyConfig, False),
    }


class GuardrailVersion(AWSObject):
    """
    `GuardrailVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-guardrailversion.html>`__
    """

    resource_type = "AWS::Bedrock::GuardrailVersion"

    props: PropsDictType = {
        "Description": (str, False),
        "GuardrailIdentifier": (str, True),
    }


class BedrockEmbeddingModelConfiguration(AWSProperty):
    """
    `BedrockEmbeddingModelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-bedrockembeddingmodelconfiguration.html>`__
    """

    props: PropsDictType = {
        "Dimensions": (integer, False),
    }


class EmbeddingModelConfiguration(AWSProperty):
    """
    `EmbeddingModelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-embeddingmodelconfiguration.html>`__
    """

    props: PropsDictType = {
        "BedrockEmbeddingModelConfiguration": (
            BedrockEmbeddingModelConfiguration,
            False,
        ),
    }


class VectorKnowledgeBaseConfiguration(AWSProperty):
    """
    `VectorKnowledgeBaseConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-vectorknowledgebaseconfiguration.html>`__
    """

    props: PropsDictType = {
        "EmbeddingModelArn": (str, True),
        "EmbeddingModelConfiguration": (EmbeddingModelConfiguration, False),
    }


class KnowledgeBaseConfiguration(AWSProperty):
    """
    `KnowledgeBaseConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-knowledgebaseconfiguration.html>`__
    """

    props: PropsDictType = {
        "Type": (str, True),
        "VectorKnowledgeBaseConfiguration": (VectorKnowledgeBaseConfiguration, True),
    }


class MongoDbAtlasFieldMapping(AWSProperty):
    """
    `MongoDbAtlasFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-mongodbatlasfieldmapping.html>`__
    """

    props: PropsDictType = {
        "MetadataField": (str, True),
        "TextField": (str, True),
        "VectorField": (str, True),
    }


class MongoDbAtlasConfiguration(AWSProperty):
    """
    `MongoDbAtlasConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-mongodbatlasconfiguration.html>`__
    """

    props: PropsDictType = {
        "CollectionName": (str, True),
        "CredentialsSecretArn": (str, True),
        "DatabaseName": (str, True),
        "Endpoint": (str, True),
        "EndpointServiceName": (str, False),
        "FieldMapping": (MongoDbAtlasFieldMapping, True),
        "VectorIndexName": (str, True),
    }


class OpenSearchServerlessFieldMapping(AWSProperty):
    """
    `OpenSearchServerlessFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-opensearchserverlessfieldmapping.html>`__
    """

    props: PropsDictType = {
        "MetadataField": (str, True),
        "TextField": (str, True),
        "VectorField": (str, True),
    }


class OpenSearchServerlessConfiguration(AWSProperty):
    """
    `OpenSearchServerlessConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-opensearchserverlessconfiguration.html>`__
    """

    props: PropsDictType = {
        "CollectionArn": (str, True),
        "FieldMapping": (OpenSearchServerlessFieldMapping, True),
        "VectorIndexName": (str, True),
    }


class PineconeFieldMapping(AWSProperty):
    """
    `PineconeFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-pineconefieldmapping.html>`__
    """

    props: PropsDictType = {
        "MetadataField": (str, True),
        "TextField": (str, True),
    }


class PineconeConfiguration(AWSProperty):
    """
    `PineconeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-pineconeconfiguration.html>`__
    """

    props: PropsDictType = {
        "ConnectionString": (str, True),
        "CredentialsSecretArn": (str, True),
        "FieldMapping": (PineconeFieldMapping, True),
        "Namespace": (str, False),
    }


class RdsFieldMapping(AWSProperty):
    """
    `RdsFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-rdsfieldmapping.html>`__
    """

    props: PropsDictType = {
        "MetadataField": (str, True),
        "PrimaryKeyField": (str, True),
        "TextField": (str, True),
        "VectorField": (str, True),
    }


class RdsConfiguration(AWSProperty):
    """
    `RdsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-rdsconfiguration.html>`__
    """

    props: PropsDictType = {
        "CredentialsSecretArn": (str, True),
        "DatabaseName": (str, True),
        "FieldMapping": (RdsFieldMapping, True),
        "ResourceArn": (str, True),
        "TableName": (str, True),
    }


class StorageConfiguration(AWSProperty):
    """
    `StorageConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-knowledgebase-storageconfiguration.html>`__
    """

    props: PropsDictType = {
        "MongoDbAtlasConfiguration": (MongoDbAtlasConfiguration, False),
        "OpensearchServerlessConfiguration": (OpenSearchServerlessConfiguration, False),
        "PineconeConfiguration": (PineconeConfiguration, False),
        "RdsConfiguration": (RdsConfiguration, False),
        "Type": (str, True),
    }


class KnowledgeBase(AWSObject):
    """
    `KnowledgeBase <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-knowledgebase.html>`__
    """

    resource_type = "AWS::Bedrock::KnowledgeBase"

    props: PropsDictType = {
        "Description": (str, False),
        "KnowledgeBaseConfiguration": (KnowledgeBaseConfiguration, True),
        "Name": (str, True),
        "RoleArn": (str, True),
        "StorageConfiguration": (StorageConfiguration, True),
        "Tags": (dict, False),
    }


class PromptVariant(AWSProperty):
    """
    `PromptVariant <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-promptversion-promptvariant.html>`__
    """

    props: PropsDictType = {
        "InferenceConfiguration": (PromptInferenceConfiguration, False),
        "ModelId": (str, False),
        "Name": (str, True),
        "TemplateConfiguration": (PromptTemplateConfiguration, False),
        "TemplateType": (str, True),
    }


class Prompt(AWSObject):
    """
    `Prompt <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-prompt.html>`__
    """

    resource_type = "AWS::Bedrock::Prompt"

    props: PropsDictType = {
        "CustomerEncryptionKeyArn": (str, False),
        "DefaultVariant": (str, False),
        "Description": (str, False),
        "Name": (str, True),
        "Tags": (dict, False),
        "Variants": ([PromptVariant], False),
    }


class PromptVersion(AWSObject):
    """
    `PromptVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-bedrock-promptversion.html>`__
    """

    resource_type = "AWS::Bedrock::PromptVersion"

    props: PropsDictType = {
        "Description": (str, False),
        "PromptArn": (str, True),
        "Tags": (dict, False),
    }


class AgentAliasHistoryEvent(AWSProperty):
    """
    `AgentAliasHistoryEvent <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-agentalias-agentaliashistoryevent.html>`__
    """

    props: PropsDictType = {
        "EndDate": (str, False),
        "RoutingConfiguration": ([AgentAliasRoutingConfigurationListItem], False),
        "StartDate": (str, False),
    }


class FlowValidation(AWSProperty):
    """
    `FlowValidation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-flow-flowvalidation.html>`__
    """

    props: PropsDictType = {
        "Message": (str, True),
    }


class TextS3Location(AWSProperty):
    """
    `TextS3Location <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-bedrock-prompt-texts3location.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, True),
        "Key": (str, True),
        "Version": (str, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class ColumnSchema(AWSProperty):
    """
    `ColumnSchema <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cleanroomsml-trainingdataset-columnschema.html>`__
    """

    props: PropsDictType = {
        "ColumnName": (str, True),
        "ColumnTypes": ([str], True),
    }


class GlueDataSource(AWSProperty):
    """
    `GlueDataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cleanroomsml-trainingdataset-gluedatasource.html>`__
    """

    props: PropsDictType = {
        "CatalogId": (str, False),
        "DatabaseName": (str, True),
        "TableName": (str, True),
    }


class DataSource(AWSProperty):
    """
    `DataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cleanroomsml-trainingdataset-datasource.html>`__
    """

    props: PropsDictType = {
        "GlueDataSource": (GlueDataSource, True),
    }


class DatasetInputConfig(AWSProperty):
    """
    `DatasetInputConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cleanroomsml-trainingdataset-datasetinputconfig.html>`__
    """

    props: PropsDictType = {
        "DataSource": (DataSource, True),
        "Schema": ([ColumnSchema], True),
    }


class Dataset(AWSProperty):
    """
    `Dataset <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cleanroomsml-trainingdataset-dataset.html>`__
    """

    props: PropsDictType = {
        "InputConfig": (DatasetInputConfig, True),
        "Type": (str, True),
    }


class TrainingDataset(AWSObject):
    """
    `TrainingDataset <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cleanroomsml-trainingdataset.html>`__
    """

    resource_type = "AWS::CleanRoomsML::TrainingDataset"

    props: PropsDictType = {
        "Description": (str, False),
        "Name": (str, True),
        "RoleArn": (str, True),
        "Tags": (Tags, False),
        "TrainingData": ([Dataset], True),
    }



import json
import os
import re
import unittest

from troposphere.template_generator import TemplateGenerator


def test_template_generator(input_filename, expected_output):
    """
    Ensures that all example outputs can be loaded into the
    template generator and back to JSON with no difference.
    """
    # we first get both outputs as JSON strings
    template = expected_output
    generated = TemplateGenerator(json.loads(template)).to_json()

    # then we make them into a dict for comparison
    template = json.loads(template)
    generated = json.loads(generated)

    assert template == generated


def load_example_tests():
    EXCLUDE_EXAMPLES = ["OpenStack_AutoScaling.py", "OpenStack_Server.py"]
    # Filter out all *.py files from the examples directory
    examples = "examples"
    regex = re.compile(r".py$", re.I)
    example_filesnames = filter(regex.search, os.listdir(examples))

    results = []
    for f in example_filesnames:
        if f in EXCLUDE_EXAMPLES:
            continue
        filename = "tests/examples_output/%s.template" % f[:-3]
        expected_output = open(filename).read()
        results.append((filename, expected_output))

    return results


def pytest_generate_tests(metafunc):
    example_data = load_example_tests()
    metafunc.parametrize("input_filename,expected_output", example_data)


if __name__ == "__main__":
    unittest.main()
